@@ -24,9 +24,11 @@
 #ifndef GJS_MODULE_H_
 #define GJS_MODULE_H_
 
+#include <config.h>
+
 #include <gio/gio.h>
 
-#include "gjs/jsapi-wrapper.h"
+#include <js/TypeDecls.h>
 
 #include "gjs/macros.h"
 
